==> senior_design_system-0.21.4.tar.gz: example/lib/pages/message_card.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class MessageCardExample extends StatefulWidget {
  const MessageCardExample({Key? key}) : super(key: key);

  @override
  State<MessageCardExample> createState() => _MessageCardExampleState();
}

class _MessageCardExampleState extends State<MessageCardExample> {
  SeniorMessageCardFeedbacks feedback = SeniorMessageCardFeedbacks.neutral;

  void onChangedFeedback(SeniorMessageCardFeedbacks feedback) {
    setState(() {
      this.feedback = feedback;
    });

    showDialog<String>(
      context: context,
      builder: (BuildContext context) => AlertDialog(
        title: Text('Feedback alterado'),
        content: Text('TODO: Montar a mensagem'),
      ),
    );
  }

  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Message Card',
      child: Scaffold(
        body: Padding(
          padding: const EdgeInsets.all(
            SeniorSpacing.normal,
          ),
          child: SingleChildScrollView(
            child: Column(
              children: [
                Panel(
                  title: 'Sem feedback',
                  child: Container(
                    height: 250.0,
                    child: SeniorMessageCard(
                      message: message,
                      padding: const EdgeInsets.symmetric(
                        horizontal: SeniorSpacing.normal,
                      ),
                    ),
                  ),
                ),
                Panel(
                  title: 'Com feedback',
                  child: Container(
                    height: 250.0,
                    child: SeniorMessageCard(
                      message: message,
                      padding: const EdgeInsets.symmetric(
                        horizontal: SeniorSpacing.normal,
                      ),
                      style: SeniorMessageCardStyle(
                        color: SeniorColors.manchesterColorRed,
                      ),
                      feedbackOptions: SeniorMessageCardFeedbackOptions(
                        label: 'Essa mensagem foi útil para você?',
                        feedback: feedback,
                        onChangedFeedback: onChangedFeedback,
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

const message = '''Caro, Sr. Emílio.
Informamos que o caminhão de placa ABC-0123 foi recebido pela Cooperativa.
Produto Soja
Peso Líquido: 25 toneladas
Percentual de umidade: 10%
Data: 13/02/2017 - 15:00

Informamos que o caminhão de placa ABC-0123 foi recebido pela Cooperativa.
Produto Soja
Peso Líquido: 25 toneladas
Percentual de umidade: 10%
Data: 13/02/2017 - 15:00
''';

==> senior_design_system-0.26.2.tar.gz: example/lib/pages/message_card.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class MessageCardExample extends StatefulWidget {
  const MessageCardExample({Key? key}) : super(key: key);

  @override
  State<MessageCardExample> createState() => _MessageCardExampleState();
}

class _MessageCardExampleState extends State<MessageCardExample> {
  SeniorMessageCardFeedbacks feedback = SeniorMessageCardFeedbacks.neutral;

  void onChangedFeedback(SeniorMessageCardFeedbacks feedback) {
    setState(() {
      this.feedback = feedback;
    });

    showDialog<String>(
      context: context,
      builder: (BuildContext context) => const AlertDialog(
        title: Text('Feedback alterado'),
        content: Text('TODO: Montar a mensagem'),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Message Card',
      child: Scaffold(
        body: Padding(
          padding: const EdgeInsets.all(
            SeniorSpacing.normal,
          ),
          child: SingleChildScrollView(
            child: Column(
              children: [
                Panel(
                  title: 'Sem feedback',
                  child: Container(
                    height: 250.0,
                    child: SeniorMessageCard(
                      message: message,
                      padding: const EdgeInsets.symmetric(
                        horizontal: SeniorSpacing.normal,
                      ),
                    ),
                  ),
                ),
                Panel(
                  title: 'Com feedback',
                  child: Container(
                    height: 250.0,
                    child: SeniorMessageCard(
                      message: message,
                      padding: const EdgeInsets.symmetric(
                        horizontal: SeniorSpacing.normal,
                      ),
                      style: const SeniorMessageCardStyle(
                        color: SeniorColors.manchesterColorRed,
                      ),
                      feedbackOptions: SeniorMessageCardFeedbackOptions(
                        label: 'Essa mensagem foi útil para você?',
                        feedback: feedback,
                        onChangedFeedback: onChangedFeedback,
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

const message = '''Caro, Sr. Emílio.
Informamos que o caminhão de placa ABC-0123 foi recebido pela Cooperativa.
Produto Soja
Peso Líquido: 25 toneladas
Percentual de umidade: 10%
Data: 13/02/2017 - 15:00

Informamos que o caminhão de placa ABC-0123 foi recebido pela Cooperativa.
Produto Soja
Peso Líquido: 25 toneladas
Percentual de umidade: 10%
Data: 13/02/2017 - 15:00
''';
